window.Gleam.initSearch([{"doc":"glib","title":"glib","content":"# glib\n\nA collection (eventually) of utilities written solely in Gleam (i.e. no erlang/js dependency)\n\n[![Package Version](https://img.shields.io/hexpm/v/glib)](https://hex.pm/packages/glib)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glib/)\n\n```sh\ngleam add glib\n```\n```gleam\nimport glib/map\n\npub fn main() {\n  let m = map.new()\n  |&gt; map.put(&quot;Key1&quot;,&quot;value&quot;)\n\n  io.debug(map.get(m, &quot;Key1&quot;))\n  // -&gt; Some(&quot;value&quot;)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glib&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"glib/hash","title":"hash","content":"pub fn hash(value: String) -&gt; Int\n\nSynonyms:\nglib/hash.hash\nglib/hash hash","url":"glib/hash.html#hash"},{"doc":"glib/hash","title":"glib/hash","content":"","url":"glib/hash.html"},{"doc":"glib/map","title":"Map","content":"pub opaque type Map(value)\n\n\nSynonyms:\nglib/map.Map\nglib/map Map","url":"glib/map.html#Map"},{"doc":"glib/map","title":"clear","content":"pub fn clear(previous_map: Map(a)) -&gt; Map(a)\n Creates a new empty map with the same sizing/loading properties as the\n passed map\nSynonyms:\nglib/map.clear\nglib/map clear","url":"glib/map.html#clear"},{"doc":"glib/map","title":"contains_key","content":"pub fn contains_key(map: Map(a), key: String) -&gt; Bool\n Returns the existence in the map for the stored key\n \n \n ## Examples\n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; contains_key(&quot;key&quot;)\n // -&gt; True\n \n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; contains_key(&quot;non-existent&quot;)\n // -&gt; False\n \n \nSynonyms:\nglib/map.contains_key\nglib/map contains_key","url":"glib/map.html#contains_key"},{"doc":"glib/map","title":"entries","content":"pub fn entries(map: Map(a)) -&gt; List(#(String, a))\n Returns a list of the tuples #(key, value) contained in the map\n \n ## Examples\n \n \n new() |&gt; entries\n // -&gt; []\n \n \n  gleam\n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; entries\n // -&gt; [#(&quot;key&quot;, &quot;value&quot;)]\n \n \nSynonyms:\nglib/map.entries\nglib/map entries","url":"glib/map.html#entries"},{"doc":"glib/map","title":"full_count","content":"pub fn full_count(map: Map(a)) -&gt; Int\n Returns a count of the number of entries in the map\n This is used for testing to compare against the cached size\n Performs a full iteration of the list incrementing for all Some(_)\n entries\nSynonyms:\nglib/map.full_count\nglib/map full_count","url":"glib/map.html#full_count"},{"doc":"glib/map","title":"get","content":"pub fn get(map: Map(a), key: String) -&gt; Option(a)\n Retrieves the option wrapped value from the map for the stored key\n \n The key may not exist so then None is returned\n \n ## Examples\n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; get(&quot;key&quot;)\n // -&gt; Ok(&quot;value&quot;)\n \n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; get(&quot;non-existent&quot;)\n // -&gt; None\n \n \nSynonyms:\nglib/map.get\nglib/map get","url":"glib/map.html#get"},{"doc":"glib/map","title":"is_empty","content":"pub fn is_empty(map: Map(a)) -&gt; Bool\n Determines whether the map is empty, i.e. contains no key/values\n \n ## Examples\n \n \n new() |&gt; is_empty\n // -&gt; True\n \n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; is_empty\n // -&gt; False\n \n \nSynonyms:\nglib/map.is_empty\nglib/map is_empty","url":"glib/map.html#is_empty"},{"doc":"glib/map","title":"keys","content":"pub fn keys(map: Map(a)) -&gt; List(String)\n Returns a list of the keys contained in the map\n \n ## Examples\n \n \n new() |&gt; keys\n // -&gt; []\n \n \n  gleam\n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; keys\n // -&gt; [&quot;key&quot;]\n \n \nSynonyms:\nglib/map.keys\nglib/map keys","url":"glib/map.html#keys"},{"doc":"glib/map","title":"list_size","content":"pub fn list_size(map: Map(a)) -&gt; Int\n Returns the internal storage size of the map\n This is mainly for testing use\nSynonyms:\nglib/map.list_size\nglib/map list_size","url":"glib/map.html#list_size"},{"doc":"glib/map","title":"new","content":"pub fn new() -&gt; Map(a)\n Creates an empty map\n The size and loading factor are set to the default\n The size is the starting size for the list that contains the values\n The loading factor is the value 0 -&gt; 1 that determines when the\n list is resized. This is the percentage of the backing list that is filled.\n For example, if the loading factor was 0.5 then when one half of the backing\n list is populated, the next addition to the Map will trigger a resize to\n ensure the map has usable space\nSynonyms:\nglib/map.new\nglib/map new","url":"glib/map.html#new"},{"doc":"glib/map","title":"new_with_size","content":"pub fn new_with_size(size: Int) -&gt; Map(a)\n Creates an empty map with specified size\n The loading factor is set to default\nSynonyms:\nglib/map.new_with_size\nglib/map new_with_size","url":"glib/map.html#new_with_size"},{"doc":"glib/map","title":"new_with_size_and_load","content":"pub fn new_with_size_and_load(size: Int, load: Float) -&gt; Map(a)\n Creates an empty map with specified size and loading factor\n load is a value 0-&gt;1 (non-inclusive) which specifies a percentage (e.g. 0.5 is 50%)\n at which point the backing list is resized\n This should be kept around 0.6-0.8 to avoid either excessive resizing or\n excessive key hash collisions\nSynonyms:\nglib/map.new_with_size_and_load\nglib/map new_with_size_and_load","url":"glib/map.html#new_with_size_and_load"},{"doc":"glib/map","title":"put","content":"pub fn put(map: Map(a), key: String, value: a) -&gt; Map(a)\n Inserts a value into the map with the given key\n \n Will replace value if key already exists\n \n ## Examples\n \n \n new() |&gt; put(&quot;key&quot;, 999) |&gt; to_string(fn(i) { int.to_string(i) })\n // -&gt; {&quot;key&quot;:999}\n \n \n \n new() |&gt; put(&quot;key&quot;, 999) |&gt; put(&quot;key2&quot;, 111) |&gt; to_string(fn(i) { int.to_string(i) })\n // -&gt; {&quot;key&quot;:999, &quot;key2&quot;:111}\n \n \n \n new() |&gt; put(&quot;key&quot;, 999) |&gt; put(&quot;key&quot;, 123) |&gt; to_string(fn(i) { int.to_string(i) })\n // -&gt; {&quot;key&quot;:123}\n \n \nSynonyms:\nglib/map.put\nglib/map put","url":"glib/map.html#put"},{"doc":"glib/map","title":"remove","content":"pub fn remove(map: Map(a), key: String) -&gt; #(Option(a), Map(a))\n Removes the specified key from the map and returns a tuple containing\n the removed option wrapped value or None and the altered map without the\n specified key\n \n ## Examples\n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; remove(&quot;key&quot;)\n // -&gt; #(Some(&quot;value&quot;), {})\n \n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; remove(&quot;non-existent&quot;)\n // -&gt; #(None, {&quot;key&quot;: &quot;value&quot;})\n \nSynonyms:\nglib/map.remove\nglib/map remove","url":"glib/map.html#remove"},{"doc":"glib/map","title":"size","content":"pub fn size(map: Map(a)) -&gt; Int\n Determines the size of the map, i.e. the number of key/values\n \n ## Examples\n \n \n new() |&gt; size\n // -&gt; 0\n \n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; size\n // -&gt; 1\n \n \nSynonyms:\nglib/map.size\nglib/map size","url":"glib/map.html#size"},{"doc":"glib/map","title":"to_string","content":"pub fn to_string(\n  map: Map(a),\n  value_to_string: fn(a) -&gt; String,\n) -&gt; String\n Returns a string representation of the passed map\n Requires a value_to_string fn to generate the output\n \n ## Examples\n \n \n new() |&gt; to_string(fn(v) { v })\n // -&gt; {}\n \n \n \n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; to_string(fn(v) { v })\n // -&gt; {&quot;key&quot;: &quot;value&quot;}\n \n \nSynonyms:\nglib/map.to_string\nglib/map to_string","url":"glib/map.html#to_string"},{"doc":"glib/map","title":"values","content":"pub fn values(map: Map(a)) -&gt; List(a)\n Returns a list of the values contained in the map\n \n ## Examples\n \n \n new() |&gt; values\n // -&gt; []\n \n \n  gleam\n new() |&gt; put(&quot;key&quot;, &quot;value&quot;) |&gt; values\n // -&gt; [&quot;value&quot;]\n \n \nSynonyms:\nglib/map.values\nglib/map values","url":"glib/map.html#values"},{"doc":"glib/map","title":"glib/map","content":" Maps are a structure similar to dict in that they map keys to values.\n Duplicate keys cannot exist and a key can map to at most one value\n \n The Keys are strings, values can be any type but values must be of the same type\n \n Maps are unordered","url":"glib/map.html"}]);